#
# spec file for package python-jupyter-kernel-test
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-jupyter-kernel-test
Version:        0.7.0
Release:        1.3
Summary:        A tool for testing Jupyter kernels
License:        BSD-3-Clause
URL:            https://github.com/jupyter/jupyter_kernel_test
Source:         https://files.pythonhosted.org/packages/source/j/jupyter_kernel_test/jupyter_kernel_test-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module hatchling >= 1.5}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-jsonschema
Requires:       python-jupyter_client >= 6.1.13
Provides:       python-jupyter_kernel_test = %{version}-%{release}
Obsoletes:      python-jupyter_kernel_test < %{version}-%{release}
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module ipykernel if %python-base >= 3.10}
BuildRequires:  %{python_module jsonschema}
BuildRequires:  %{python_module jupyter_client >= 6.1.13}
# /SECTION
%python_subpackages

%description
jupyter_kernel_test is a tool for testing Jupyter kernels. It tests kernels for
successful code execution and conformance with the Jupyter Messaging Protocol.

%prep
%setup -q -n jupyter_kernel_test-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONDONTWRITEBYTECODE=1
%{python_expand # don't test anything on python39: no ipykernel anymore
export PYTHONPATH=%{buildroot}%{$python_sitelib}
if [ ${python_flavor} != "python39" ]; then
  $python -m unittest -v
fi
}

%files %{python_files}
%license LICENSE
%{python_sitelib}/jupyter_kernel_test
%{python_sitelib}/jupyter_kernel_test-%{version}*-info

%changelog
* Fri Mar 29 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.7.0
  * Maintenance and upkeep improvements
* Thu Mar  7 2024 Ben Greiner <code@bnavigator.de>
- Stop testing on python39: no ipykernel
* Sun Sep 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.6.0
  * Add test for Jep #65 #134 (@Hind-M)
  * Drop Python 3.7 support #135 (@blink1073)
* Sun Feb  5 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.5.0
  * Fix client 8 compat #109 (@blink1073)
  * CI and maintenance cleanups
* Wed Oct 26 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.4.5
  * Switch to hatch backend #100 (@blink1073)
  * Fix flake8 v5 compat #95 (@blink1073)
  * Adopt flake8 and update ci #75 (@blink1073)
  * Add git-blame-ignore-revs #74 (@blink1073)
  * Drop support for py36 #72 (@blink1073)
  * Fix typos #71 (@martinRenou)
* Sat Mar 26 2022 Ben Greiner <code@bnavigator.de>
- Initial specfile for 0.4.3
